/**
 * 
 */
package com.midwest.rfid;

import com.ibm.jsdt.checkpoints.StartupCheckpoint;
import com.ibm.jsdt.facade.DeployerNotRunningException;
import com.ibm.jsdt.facade.VariableConfiguration;
import com.ibm.jsdt.support.SupportHelper;

/**
 * @author erichmagee
 *
 */
public class RFIDStartup extends StartupCheckpoint {

	/**
	 * Each startup checkpoint subclass must implement this method.
	 * It controls the flow of how your startup checkpoint class runs.
	 *
	 * The deployment wizard invokes this class as the entry point into
	 * your startup checkpoint class. This runs immediately before the
	 * deployment wizard interface is displayed. In order to override the defaults
	 * for the progress dialog, override the initializeProgressDialog method.
	 *
	 * @param silentMode - Indicates whether or not this startup checkpoint is 
	 * being run in silent mode or in interactive mode. If silentMode is true then 
	 * do not surface any graphical user interfaces.
	 *
	 * @return An integer indicating how the deployment wizard should proceed.
	 * Appropriate values are listed below. Any other return code is 
	 * interpreted as failure, and the deployment wizard does not launch. 
	 * <ul> 
	 * <li>LAUNCH_DEPLOYER	 - 	indicates success, and the deployment wizard launches 
	 * <li>ABORT_DEPLOYER   - 	indicates an error occurred. A dialog with a default error message is displayed 
	 * and the deployment is not launched. You can override the dialog title and text. 
	 * <li>PROMPT_USER      -  indicates a warning occurred. A dialog with a default warning message is displayed. 
	 * The user is presented with the option to continue and launch the deployment wizard or to cancel. 
	 * You can override the dialog title and text. 
	 * </ul> 
	 
	 */
	@Override
	public int execute(boolean silentMode) {

		int RC = LAUNCH_DEPLOYER;

		String taskID = null;
		String applicationID = "MidwestTrucking";
		String variableName = "stagingServerOs";
		String stagingServerOsValue = null;
		boolean override = true;
		
		SupportHelper helper = new SupportHelper();
		VariableConfiguration vc = null;
		
		try {
			vc = new VariableConfiguration();			
			if (helper.isLinux()) {
				taskID = "linux";
				stagingServerOsValue = "Linux";				
			}
			else {
				taskID = "windows";
				stagingServerOsValue = "Windows";
			}
 
			try {
				vc.setVariableValue(taskID, applicationID, variableName, stagingServerOsValue, override);				
			}
			catch (Exception e) {
				setUserPromptDialogTitle("Midwest Trucking Solutions");
				setUserPromptDialogMessage("Error Installing Midwest Trucking RFID Solution.");
				RC = ABORT_DEPLOYER;				
			}			
		}
		catch (DeployerNotRunningException dnre) {
			if (!silentMode) {				
				setUserPromptDialogTitle("Midwest Trucking Solutions");
				setUserPromptDialogMessage("Error Installing Midwest Trucking RFID Solution.");
				RC = ABORT_DEPLOYER;
				logMessage(dnre.toString());
			}
		}
		
		return RC;
	}
}